@@ -249,7 +249,10 @@ OSRIsProjected <- function(obj) {
                     }
                 }
                 coordOp <- .Call("project_ng_coordOp", proj,
-                    as.logical(inv), aoi, PACKAGE="rgdal")
+                    as.logical(inv), aoi, as.logical(use_ob_tran), PACKAGE="rgdal")
+                s2t <- strsplit(coordOp, " ")[[1]]
+                if (length(s2t) == 0L) stop("malformed pipeline found")
+                coordOp <- paste("+", s2t, sep="", collapse=" ")
             }
             if (verbose) cat(strwrap(coordOp), sep="\n")
             res <- .Call("project_ng",
@@ -257,8 +260,6 @@ OSRIsProjected <- function(obj) {
                 as.double(xy[,1]),
                 as.double(xy[,2]),
                 NULL,
-                as.logical(inv),
-                as.logical(use_ob_tran),
                 coordOp,
                 PACKAGE="rgdal")
         } else {
@@ -442,12 +443,14 @@ if (!isGeneric("spTransform"))
                     else use_ob_tran1 <- TRUE
                     if (is.null(coordOp)) {
                         out_coordOp <- .Call("project_ng_coordOp", proj,
-                            as.logical(inv), NULL, #as.logical(use_ob_tran1),
+                            as.logical(inv), NULL, as.logical(use_ob_tran1),
                             PACKAGE="rgdal")
+                        s2t <- strsplit(out_coordOp, " ")[[1]]
+                        if (length(s2t) == 0L) stop("malformed pipeline found")
+                        out_coordOp <- paste("+", s2t, sep="", collapse=" ")
                     }
                     res <- .Call("project_ng", as.integer(n), 
                         as.double(crds[,1]), as.double(crds[,2]), NULL,
-                        as.logical(inv), as.logical(use_ob_tran1),
                         out_coordOp, PACKAGE="rgdal")
                 }
             } else {
@@ -484,13 +487,15 @@ if (!isGeneric("spTransform"))
                     else use_ob_tran1 <- TRUE
                     if (is.null(coordOp)) {
                         out_coordOp <- .Call("project_ng_coordOp", proj,
-                            as.logical(inv), NULL, #as.logical(use_ob_tran1),
+                            as.logical(inv), NULL, as.logical(use_ob_tran1),
                             PACKAGE="rgdal")
+                        s2t <- strsplit(out_coordOp, " ")[[1]]
+                        if (length(s2t) == 0L) stop("malformed pipeline found")
+                        out_coordOp <- paste("+", s2t, sep="", collapse=" ")
                     }
                     res <- .Call("project_ng", as.integer(n), 
                         as.double(crds[,1]), as.double(crds[,2]),
-                        as.double(crds[,3]), as.logical(inv), 
-                        as.logical(use_ob_tran1), out_coordOp, PACKAGE="rgdal")
+                        as.double(crds[,3]), out_coordOp, PACKAGE="rgdal")
                 }
             } else {
 	    res <- .Call("transform", from_args, to_args, n,
@@ -508,8 +513,12 @@ if (!isGeneric("spTransform"))
 	    crds[,1:3] <- cbind(res[[1]], res[[2]], res[[3]])
         }
 	# make sure coordinate names are set back:
-        if (new_proj_and_gdal()) assign(".last_coordOp", gsub(" ",
-            " +", paste0("+", out_coordOp)), envir=.RGDAL_CACHE)
+        if (new_proj_and_gdal()) {
+            if (substring(out_coordOp, 1, 1) != "+") {
+                out_coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
+            }
+            assign(".last_coordOp", out_coordOp, envir=.RGDAL_CACHE)
+        }
 	dimnames(crds)[[2]] <- crds.names
 	x <- SpatialPoints(coords=crds, proj4string=CRSobj)
 	x
@@ -577,12 +586,14 @@ setMethod("spTransform", signature("SpatialGridDataFrame", "CRS"),
                 else use_ob_tran1 <- TRUE
                 if (is.null(coordOp)) {
                     coordOp <- .Call("project_ng_coordOp", proj,
-                        as.logical(inv), NULL, #as.logical(use_ob_tran1),
+                        as.logical(inv), NULL, as.logical(use_ob_tran1),
                         PACKAGE="rgdal")
+                    s2t <- strsplit(coordOp, " ")[[1]]
+                    if (length(s2t) == 0L) stop("malformed pipeline found")
+                    coordOp <- paste("+", s2t, sep="", collapse=" ")
                 }
                 res <- .Call("project_ng", as.integer(n), 
                     as.double(crds[,1]), as.double(crds[,2]), NULL,
-                    as.logical(inv), as.logical(use_ob_tran1),
                     coordOp, PACKAGE="rgdal")
                 out_coordOp <- coordOp
             }
@@ -600,7 +611,13 @@ setMethod("spTransform", signature("SpatialGridDataFrame", "CRS"),
 	}
 	crds <- cbind(res[[1]], res[[2]])
 	x <- Line(coords=crds)
-        if (new_proj_and_gdal()) attr(x, "coordOp") <- out_coordOp
+        if (new_proj_and_gdal()) {
+            if (substring(out_coordOp, 1, 1) == "+") {
+                attr(x, "coordOp") <- out_coordOp
+            } else {
+                attr(x, "coordOp") <-  gsub(" ", " +", paste0("+", out_coordOp))
+            }
+        }
 	x
 }
 
@@ -619,8 +636,8 @@ setMethod("spTransform", signature("SpatialGridDataFrame", "CRS"),
                 use_ob_tran=use_ob_tran, coordOp=coordOp,
                 enforce_xy=enforce_xy, aoi=aoi)
             if (is.null(coordOp) && new_proj_and_gdal() && i == 1) {
-                out_coordOp <- attr(output[[i]], "coordOp")
-                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
+                coordOp <- attr(output[[i]], "coordOp")
+#                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
             }
             attr(output[[i]], "coordOp") <- NULL
         }
@@ -740,8 +757,8 @@ setMethod("spTransform", signature("SpatialGridDataFrame", "CRS"),
                 use_ob_tran=use_ob_tran, coordOp=coordOp,
                 enforce_xy=enforce_xy, aoi=aoi)
             if (is.null(coordOp) && new_proj_and_gdal() && i == 1) {
-                out_coordOp <- attr(output[[i]], "coordOp")
-                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
+                coordOp <- attr(output[[i]], "coordOp")
+#                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
             }
             attr(output[[i]], "coordOp") <- NULL
         }
@@ -790,12 +807,14 @@ setMethod("spTransform", signature("SpatialLinesDataFrame", "CRS"), spTransform.
                 else use_ob_tran1 <- TRUE
                 if (is.null(coordOp)) {
                     coordOp <- .Call("project_ng_coordOp", proj,
-                        as.logical(inv), NULL, #as.logical(use_ob_tran1),
+                        as.logical(inv), NULL, as.logical(use_ob_tran1),
                         PACKAGE="rgdal")
+                    s2t <- strsplit(coordOp, " ")[[1]]
+                    if (length(s2t) == 0L) stop("malformed pipeline found")
+                    coordOp <- paste("+", s2t, sep="", collapse=" ")
                 }
                 res <- .Call("project_ng", as.integer(n), 
                     as.double(crds[,1]), as.double(crds[,2]), NULL,
-                    as.logical(inv), as.logical(use_ob_tran1),
                     coordOp, PACKAGE="rgdal")
                 out_coordOp <- coordOp
             }
@@ -813,7 +832,13 @@ setMethod("spTransform", signature("SpatialLinesDataFrame", "CRS"), spTransform.
 	}
 	crds <- cbind(res[[1]], res[[2]])
 	x <- Polygon(coords=crds)
-        if (new_proj_and_gdal()) attr(x, "coordOp") <- out_coordOp
+        if (new_proj_and_gdal()) {
+            if (substring(out_coordOp, 1, 1) == "+") {
+                attr(x, "coordOp") <- out_coordOp
+            } else {
+                attr(x, "coordOp") <-  gsub(" ", " +", paste0("+", out_coordOp))
+            }
+        }
 	x
 }
 
@@ -831,14 +856,14 @@ setMethod("spTransform", signature("SpatialLinesDataFrame", "CRS"), spTransform.
                 use_ob_tran=use_ob_tran, coordOp=coordOp,
                 enforce_xy=enforce_xy, aoi=aoi)
             if (is.null(coordOp) && new_proj_and_gdal() && i == 1) {
-                out_coordOp <- attr(output[[i]], "coordOp")
-                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
+                coordOp <- attr(output[[i]], "coordOp")
+#                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
             }
             attr(output[[i]], "coordOp") <- NULL
         }
 	res <- Polygons(output, ID)
         if (!is.null(comment(x))) comment(res) <- comment(x)
-        if (new_proj_and_gdal()) attr(res, "coordOp") <- out_coordOp
+        if (new_proj_and_gdal()) attr(res, "coordOp") <- coordOp
 	res
 }
 
@@ -952,8 +977,8 @@ setMethod("spTransform", signature("SpatialLinesDataFrame", "CRS"), spTransform.
                 use_ob_tran=use_ob_tran, coordOp=coordOp,
                 enforce_xy=enforce_xy, aoi=aoi)
             if (is.null(coordOp) && new_proj_and_gdal() && i == 1) {
-                out_coordOp <- attr(output[[i]], "coordOp")
-                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
+                coordOp <- attr(output[[i]], "coordOp")
+#                coordOp <-  gsub(" ", " +", paste0("+", out_coordOp))
             }
             attr(output[[i]], "coordOp") <- NULL
         }
